==> blobAndConquer-0.1-1.tar.gz: BlobAndConquer/src/game/CGame.h <==
/*
Copyright (C) 2005 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

typedef struct InfoMessage {

	bool redraw;
	String message;
	int type;
	float life;

};

class Game {

	private:
		
		static Game instance;
		
		Engine *engine;
		Mouse *mouse;
		
	Game();

	public:
		
		bool inGame;
		bool training;
		
		int weaponIndex;
		Weapon *selectedWeapon;
		Weapon *weapon[4];
		int weaponId[4];
		
		Item *item[5];
		int itemId[5];
		
		float teekaAvailableTimer;
		Vector teekaCheckPoint;
		int teekaWeapon;
				
		int currentOrders;
		
		float comboTimer;
		int comboHits;

		Properties statistics;
		
		String mission;
		String targetMission;
		String targetLocation;
		
		InfoMessage infoMessage[4];
		InfoMessage gameplayMessage;
		
		int keyboard[CTRL_MAXIMUM];
		int joystick[CTRL_MAXIMUM];
		int mouseCtrl[CTRL_MAXIMUM];
		
		int joystickDeadZone;
		int mouseSensitivity;
		
		float hours, minutes, seconds;
		
		bool savingRestricted;
		bool canSaveGame;
		int saveSlot;
		
		bool changingLevel;
		bool retrying;
		
		float cameraHeight, cameraRadius;
		float cameraDirRadian, cameraAdjustedRadian;
		float cameraDirDegrees;
		Vector cameraDir;
		
		Vector checkpoint;
		bool mustChangeWeapon;
		
		bool strafeLock;
		Point aimDirection;
		
		Vector targetLock;
		
		int missionStatus;
		float missionOverTimer;
		
		// -------- Cheats... Try not to abuse these, guys... -----------
		bool cheatHealth;
		bool cheatShield;
		bool cheatAmmo;
		bool cheatNPC;
		bool cheatClip;
		bool cheatFly;
		bool cheatSave;
		
		//--------- Debugging Stuff. See main.cpp for usages -----------
		bool nomonsters;
		bool noitems;
		bool nofeatures;
		bool allStatic;
		bool cheatsActive;

	~Game();
	static Game *getInstance();
	
	void clear();
	void destroy();
	
	void setDefaultKeyboardControls();

	void alterStat(char *statName, float value);
	float getStatistic(char *name);
	
	void setMissionStatus(int status);
	
	void setInfoMessage(int type, char *message, ...);
	void setGamePlayMessage(char *message, ...);
	void setGamePlayMessage(int time, char *message, ...);
	
	int getFreeInventorySlot();
	bool hasItem(char *name);
	void removeItem(char *name);
	
	int getSelectedWeaponSlot();
	
	void changeCameraRotation(float r);
	
	void incTime(float seconds);
	
	void doComboTimer(float td);
	
	bool isControl(int control);
	void resetControl(int control);
	
	void load(Properties *props);
	void save(FILE *fp);

};

==> blobAndConquer-0.2-1.tar.gz: BlobAndConquer/src/game/CGame.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

typedef struct InfoMessage {

	bool redraw;
	String message;
	int type;
	float life;

};

class Game {

	private:
		
		static Game instance;
		
		Engine *engine;
		Mouse *mouse;
		
	Game();

	public:
		
		bool inGame;
		bool training;
		bool testing;
		
		int weaponIndex;
		Weapon *selectedWeapon;
		Weapon *weapon[4];
		int weaponId[4];
		
		Item *item[5];
		int itemId[5];
		
		float teekaAvailableTimer;
		Vector teekaCheckPoint;
		int teekaWeapon;
				
		int currentOrders;
		bool dropGrappleHooks;
		
		float comboTimer;
		int comboHits;

		Properties statistics;
		
		String mission;
		String targetMission;
		String targetLocation;
		
		InfoMessage infoMessage[4];
		InfoMessage gameplayMessage;
		
		int keyboard[CTRL_MAXIMUM];
		int joystick[CTRL_MAXIMUM];
		int mouseCtrl[CTRL_MAXIMUM];
		
		int joystickDeadZone;
		int mouseSensitivity;
		
		float hours, minutes, seconds;
		
		bool savingRestricted;
		bool canSaveGame;
		int saveSlot;
		
		bool cheatsEnabled;
		
		bool changingLevel;
		bool retrying;
		
		float cameraHeight, cameraRadius;
		float cameraDirRadian, cameraAdjustedRadian;
		float cameraDirDegrees;
		Vector cameraDir;
		
		Vector checkpoint;
		bool mustChangeWeapon;
		
		float autoFaceTimer;
		bool autoLockTarget;
		Vector targetLock;
		
		int missionStatus;
		float missionOverTimer;
		bool doingCutscene;
		
		// -------- Cheats... Try not to abuse these, guys... -----------
		bool cheatHealth;
		bool cheatShield;
		bool cheatAmmo;
		bool cheatStun;
		bool cheatNPC;
		bool cheatClip;
		bool cheatFly;
		bool cheatSave;
		bool cheatBlind;
		bool cheatOxygen;
		bool cheatItems;
		
		//--------- Debugging Stuff. See main.cpp for usages -----------
		bool nomonsters;
		bool noitems;
		bool nofeatures;
		bool allStatic;
		bool cheatsActive;

	~Game();
	static Game *getInstance();
	
	void clear();
	void destroy();
	
	void setDefaultKeyboardControls();

	void alterStat(char *statName, float value);
	float getStatistic(char *name);
	
	void setMissionStatus(int status);
	
	void setInfoMessage(int type, char *message, ...);
	void setGamePlayMessage(char *message, ...);
	void setGamePlayMessage(int time, char *message, ...);
	
	int getFreeInventorySlot();
	int getItemSlot(char *name);
	bool hasItem(char *name);
	int removeItem(char *name);
	
	int getSelectedWeaponSlot();
	
	void removeAllItems();
	
	void changeCameraRotation(float r);
	
	void incTime(float seconds);
	
	void doComboTimer(float td);
	
	bool isControl(int control);
	void resetControl(int control);
	
	void load(Properties *props);
	void save(FILE *fp);

};
